.. index::
    single: How-to

###############
 How-to guides
###############

The how-to guides provide clear and concise instructions for users to
accomplish specific tasks or solve particular problems. They aim to help with
step-by-step guidance.

.. toctree::
   :maxdepth: 1

   use-frontend-as-component
   inline-editing
   add-frontend-plugins
   extend-frontend-plugins
   add-tab-style
   create-themes
   migrate-bootstrap4
   migrate-3rd-party-plugins
   internal-link-targets
